qcacmn: change name for ZeroCACDFS

The term "agile" is used by hardware for swift/fast channel change.
Use precac for the zeroCACDFS instead.

Change-Id: I35f4d61cc93b3542feb8b286cbdf3a4474df5a75
Crs-fixed: 1073945
diff --git a/wmi_unified_param.h b/wmi_unified_param.h
index e789afe..fd2c051 100644
--- a/wmi_unified_param.h
+++ b/wmi_unified_param.h
@@ -379,7 +379,7 @@
  * @is_chan_passive: is this passive channel
  * @allow_ht: HT allowed in chan
  * @allow_vht: VHT allowed on chan
  * @dfs_set_agile: is agile mode
  * @phy_mode: phymode (vht80 or ht40 or ...)
  * @cfreq1: centre frequency on primary
  * @cfreq2: centre frequency on secondary
@@ -401,7 +401,7 @@
 		is_chan_passive:1,
 		allow_ht:1,
 		allow_vht:1,
-		dfs_set_agile:1;
+		set_agile:1;
 	uint32_t phy_mode;
 	uint32_t cfreq1;
 	uint32_t cfreq2;
@@ -379,7 +379,7 @@
  * @allow_ht: HT allowed in chan
  * @allow_vht: VHT allowed on chan
- * @dfs_set_agile: is agile mode
+ * @set_agile: is agile mode
  * @phy_mode: phymode (vht80 or ht40 or ...)
  * @cfreq1: centre frequency on primary